@@ -386,6 +386,11 @@ class test_list_expressions():
             x = Expression(lst)
             assert_pickle_equal(x)
 
+def strip_line_numbers_from_traceback(s):
+    s = re.sub('(?<=[.]c):[0-9]+(?=[)])', '', s)
+    s = re.sub(', line [0-9]+(?=, )', '', s)
+    return s
+
 class test_expression_parser():
 
     def test_badstring(self):
@@ -400,11 +405,11 @@ class test_expression_parser():
         with interim(sys, stderr=stderr):
             with raises(ExpressionSyntaxError):
                 Expression.from_stream(42)
-        stderr = re.sub(':[0-9]+', '', stderr.getvalue())
-        assert_equal(stderr, '''\
+        stderr = strip_line_numbers_from_traceback(stderr.getvalue())
+        assert_multi_line_equal(stderr, '''\
 Unhandled exception (42)
 Traceback (most recent call last):
-  File "sexpr.pyx", line 167, in djvu.sexpr._myio_getc (djvu/sexpr.c)
+  File "sexpr.pyx", in djvu.sexpr._myio_getc (djvu/sexpr.c)
 AttributeError: 'int' object has no attribute 'read'
 
 ''')
@@ -455,26 +460,27 @@ AttributeError: 'int' object has no attribute 'read'
 class test_expression_writer():
 
     expr = Expression([Symbol('eggs'), Symbol('ham')])
+    repr = '(eggs ham)'
 
     def test_bad_io(self):
         stderr = StringIO()
         with interim(sys, stderr=stderr):
             self.expr.print_into(42)
-        stderr = re.sub(':[0-9]+', '', stderr.getvalue())
+        stderr = strip_line_numbers_from_traceback(stderr.getvalue())
         expected_stderr = '''\
 Unhandled exception (42)
 Traceback (most recent call last):
-  File "sexpr.pyx", line 153, in djvu.sexpr._myio_puts (djvu/sexpr.c)
+  File "sexpr.pyx", in djvu.sexpr._myio_puts (djvu/sexpr.c)
 AttributeError: 'int' object has no attribute 'write'
 
 '''
         expected_stderr *= len(stderr) // len(expected_stderr)
-        assert_equal(stderr, expected_stderr)
+        assert_multi_line_equal(stderr, expected_stderr)
 
     def test_stringio(self):
         fp = StringIO()
         self.expr.print_into(fp)
-        assert_equal(fp.getvalue(), '(eggs ham)')
+        assert_equal(fp.getvalue(), self.repr)
 
     def test_fileio_text(self):
         fp = tempfile.TemporaryFile(mode='w+t')
@@ -482,7 +488,7 @@ AttributeError: 'int' object has no attribute 'write'
             assert_equal(type(fp), file)
         self.expr.print_into(fp)
         fp.seek(0)
-        assert_equal(fp.read(), '(eggs ham)')
+        assert_equal(fp.read(), self.repr)
 
     def test_fileio_binary(self):
         fp = tempfile.TemporaryFile(mode='w+b')
@@ -490,6 +496,11 @@ AttributeError: 'int' object has no attribute 'write'
             assert_equal(type(fp), file)
         self.expr.print_into(fp)
         fp.seek(0)
-        assert_equal(fp.read(), b('(eggs ham)'))
+        assert_equal(fp.read(), b(self.repr))
+
+class test_expression_writer_nonascii(test_expression_writer):
+
+    expr = Expression(u('żółw'))
+    repr = r'"\305\274\303\263\305\202w"'
 
 # vim:ts=4 sw=4 et
